pub enum PeerError {
Send,
Read(Error),
Parse(Error),
UnexpectedMessage,
MessageTooBig,
MagicBitsMismatch,
TooManyMessages,
PingTimeout,
Channel,
Transport(TransportError),
}Expand description
Enum for diverse variants of errors when dealing with a Peer
Variants
Send
Error while sending data to a peer
Read(Error)
Error while reading data from a peer
Parse(Error)
Error while parsing message
UnexpectedMessage
Peer sent us a message that we aren’t expecting
MessageTooBig
Peer sent us a message that is too big
MagicBitsMismatch
Peer sent us a message with the wrong magic bits
TooManyMessages
Peer sent us too many messages in a short period of time
PingTimeout
Peer timed out a ping message
Channel
Channel error
Transport(TransportError)
Transport error